package com.muyu.common.saas.interceptor;

import com.muyu.common.core.utils.ServletUtils;
import com.muyu.common.core.utils.SpringUtils;
import com.muyu.common.saas.constents.SaaSConstant;
import com.muyu.common.saas.exception.SaaSException;
import com.muyu.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.many.datasource.role.DynamicDataSource;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.AsyncHandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * SaaS拦截器 SaaSInterceptor
 *
 * @author DeKangLiu
 * Date 2024/6/4 14:39
 */
public class SaaSInterceptor implements AsyncHandlerInterceptor {

    /**
     * 之前
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        if (!(handler instanceof HandlerMethod)){
            return true;
        }

        String SaasKey = ServletUtils.getHeader(request, SaaSConstant.SAAS_KEY);

        if (SaasKey==null){
            throw new SaaSException("SaaS非法访问");
        } else {
            DynamicDataSource dynamicDataSource = SpringUtils.getBean(DynamicDataSource.class);
            if (!dynamicDataSource.hashKye(SaasKey)){
                throw new SaaSException("SaaS非法访问");
            }
        }
        DynamicDataSourceHolder.setDynamicDataSourceKey(SaasKey);
        return true;
    }

    /**
     * 之后
     */
    @Override
    public void afterConcurrentHandlingStarted(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

}
