package com.muyu.many.datasource.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.security.utils.SecurityUtils;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 车辆录入对象 vehicle
 *
 * @author muyu
 * @date 2024-05-27
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName(value = "vehicle")
public class Vehicle extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 车辆id */
    @TableId(value = "id",type = IdType.AUTO)
    private Long id;

    /** 车辆vin */
    private String vin;

    /** 品牌 */
    private String brand;

    /** 型号 */
    private String model;

    /** 生产日期 */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date productionDate;

    /** 车身类型 */
    private String bodyType;

    /** 车身颜色 */
    private String color;

    /** 发动机排量 */
    private BigDecimal engineCapacity;

    /** 燃油类型 */
    private String fuelType;

    /** 变速器类型 */
    private String transmission;

    /** 驱动方式 */
    private String driveType;

    /** 行驶里程 */
    @Excel(name = "行驶里程")
    @ApiModelProperty(name = "行驶里程", value = "行驶里程")
    private BigDecimal mileage;

    /** 注册日期 */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date registrationDate;

    /** 车牌号码 */
    private String licenseNumber;

    /** 持有者 */
    private String holder;

    /** 车辆类型 */
    private String vehicleType;


}
